.. _core_device_general_settings:

General Settings
----------------

Configure the General Settings to configure the device plugin.

:Device Auto Enrolment: When new devices connect to the Peek server, Peek will mark them
    as enrolled automatically.

.. image:: general_settings.png

